@@ -1,24 +1,25 @@
 package Mojolicious::Plugin::Credentials;
-$Mojolicious::Plugin::Credentials::VERSION = '0.004';
+$Mojolicious::Plugin::Credentials::VERSION = '0.005';
 use Mojo::Base 'Mojolicious::Plugin', -signatures;
 
 use Carp 'croak';
 use Crypt::Credentials 0.002;
 use File::Spec::Functions 'catdir';
 
+use Env qw/@MOJO_CREDENTIALS_KEYS $MOJO_CREDENTIALS_DIR/;
+
 sub _get_keys($self, $config) {
 	if ($config->{keys}) {
 		return @{ $config->{keys} };
-	} elsif (defined $ENV{MOJO_CREDENTIALS_KEY}) {
-		my @encoded_keys = split /:/, $ENV{MOJO_CREDENTIALS_KEYS};
-		return map { pack 'H*', $_ } @encoded_keys;
+	} elsif (@MOJO_CREDENTIALS_KEYS) {
+		return map { pack 'H*', $_ } @MOJO_CREDENTIALS_KEYS;
 	} else {
 		croak 'No credentials key given';
 	}
 }
 
 sub register($self, $app, $config) {
-	my $dir  = $config->{dir} // $ENV{MOJO_CREDENTIALS_DIR} // catdir($app->home, 'credentials');
+	my $dir  = $config->{dir} // $MOJO_CREDENTIALS_DIR // catdir($app->home, 'credentials');
 	my @keys = $self->_get_keys($config);
 
 	my $credentials = Crypt::Credentials->new(dir => $dir, keys => \@keys);
@@ -44,7 +45,7 @@ Mojolicious::Plugin::Credentials - A credentials store in mojo
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -52,7 +53,7 @@ version 0.004
 
  plugin Credentials => { keys => \@keys };
 
- my ($password) = app->credentials->get('google');
+ my $password = app->credentials->get('google');
 
  # Mojolicious
 
